

set -ex



test -L $PREFIX/lib/libcusparse.so.12.5.3.3
test -L $PREFIX/lib/libcusparse.so.12
test -L $PREFIX/targets/sbsa-linux/lib/libcusparse.so.12
test -f $PREFIX/targets/sbsa-linux/lib/libcusparse.so.12.5.3.3
exit 0
